@@ -3,10 +3,11 @@ use warnings;
 use MRO::Compat 'c3';
 
 package WebService::Shippo::Object;
+require WebService::Shippo::ListObject;
 use Carp         ( 'croak' );
 use JSON::XS     ();
 use Scalar::Util ( 'blessed', 'reftype' );
-use namespace::clean;
+use overload ( fallback => 1, '""' => 'to_string' );
 
 sub class
 {
@@ -58,7 +59,9 @@ sub rebless
                     # Correctly bless the members of the list
                     bless $thing, $self->class;
                 }
-                $self->rebless( $self->class . 'List' );
+                my $class = $self->class;
+                bless $self, 'WebService::Shippo::ListObject';
+                $self->rebless( $class . 'List' );
             }
             return $self;
         }
@@ -105,6 +108,12 @@ sub refresh_from
         my ( $self ) = @_;
         return { %{$self} };
     }
+    
+    sub to_string
+    {
+        my ( $self ) = @_;
+        return $json->encode( $self );
+    }
 }
 
 1;
