@@ -2,22 +2,10 @@ use strict;
 use warnings;
 
 package WebService::Shippo::Request;
+require WebService::Shippo::Resource;
 use JSON::XS    ();
 use LWP         ();
-use URI::Encode ( 'uri_encode' );
-use namespace::clean;
-
-{
-    my $value = LWP::UserAgent->new;
-
-    sub user_agent
-    {
-        my ( $class, $new_value ) = @_;
-        return $value unless @_ > 1;
-        $value = $new_value;
-        return $class;
-    }
-}
+use URI::Encode ( 'uri_encode' );use namespace::clean;
 
 {
     my $value = { 'Content-Type' => 'application/json',
@@ -27,6 +15,28 @@ use namespace::clean;
     sub headers { wantarray ? %$value : $value }
 }
 
+{
+    my $value = undef;
+
+    sub user_agent
+    {
+        my ( $class, $new_value ) = @_;
+        return $value unless @_ > 1;
+        $value = $new_value;
+        if ( $value->can( 'agent' ) ) {
+            my $prod = 'Shippo/' . Shippo::Resource->DEFAULT_API_BASE_PATH;
+            $prod .= " WebService\::Shippo/$WebService::Shippo::VERSION";
+            $prod .= ' ' . $value->_agent
+                if $value->can( '_agent' );
+            $value->agent( $prod );
+            headers->{'X-Shippo-Client-User-Agent'} = $value->agent;
+        }
+        return $class;
+    }
+
+    __PACKAGE__->user_agent( LWP::UserAgent->new );
+}
+
 sub query_string
 {
     my ( $invocant, $params ) = @_;
